@@ -1,9 +1,12 @@
 from .db import Db as __Db__
-from .log import logger
+# from .log import logger
 from config.application import settings
 # import config.application_model
 from .result import MyResponse, MyResponseError, ResultError, MyException
 from .tools import IdWorker
+import logging
+
+logger=logging.getLogger()
 
 settings = settings
 
