@@ -1,15 +1,13 @@
-from config.application_model import Option
 import enum
-from typing import Any, Optional
-from pydantic import BaseModel
-from fastapi.responses import Response
-
-import typing
 import json
+import typing
+from typing import Any, Optional
+
+from fastapi.responses import Response
+from pydantic import BaseModel
+
 from . import settings
 
-from enum import Enum
-from . import settings
 
 # 基础错误代码定义
 # class ErrCode(enum):
@@ -17,6 +15,7 @@ from . import settings
 #     LOGIN_FAIL: 1000
 #     REQUEST_VALIDATE_FAIL: 2000
 #     FILE_ERROR: 3000
+#     DB_ERROR: 4000
 #     COMMON_ERROR: 8000
 #     UNKNOWN_ERROR: 9000
 
@@ -47,18 +46,9 @@ class ResultError(BaseModel):
     msg: str = ''  # 对外暴漏的错误信息
     detail: Any = None  # 对外暴漏的错误详细信息
     errid: str = ''  # 记录到日志中的错误id，排查问题时使用
-    errmsg:Optional[Any] = None  # 不公开的错误信息，排查问题使用
+    errmsg: Optional[Any] = None  # 不公开的错误信息，排查问题使用
     traceback: Optional[str] = None  # 堆栈信息，排查问题使用
 
-    # def getDict(self):
-    #     dic = {}
-    #     dic.update('code', self.code)
-    #     dic.update('msg', self.msg)
-    #     dic.update('detail', self.detail)
-    #     dic.update('errid', self.errid)
-    #     dic.update('errmsg', self.errmsg)
-    #     dic.update('traceback', self.traceback)
-
 
 class MyResponseError(Response):
     media_type = "application/json"
